@@ -1,7 +1,7 @@
 # Mail::Alias.pm
 #
-# Copyright (c) 1995 Graham Barr <Graham.Barr@tiuk.ti.com>. All rights
-# reserved. This program is free software; you can redistribute it and/or
+# Copyright (c) 1995 Graham Barr <gbarr@ti.com>. All rights reserved.
+# This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
 
@@ -48,7 +48,7 @@ B<NOTE: This package is unfinished>
 
 =head1 AUTHOR
 
-Graham Barr <Graham.Barr@tiuk.ti.com>
+Graham Barr <gbarr@ti.com>
 
 =head1 COPYRIGHT
 
@@ -61,7 +61,7 @@ as Perl itself.
 use Carp;
 use vars qw($VERSION);
 
-$VERSION = "1.04";
+$VERSION = do { my @r=(q$Revision: 1.6 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r};
 sub Version { $VERSION }
 
 sub new {
